@@ -56,7 +56,7 @@ class GitLab(object):
         return any([x['username'] == username for x in self.group_members(group)])
 
     def is_self_member_of_group(self, group):
-        r = self.s.get(self.s.api + f'/user')
+        r = self.s.get(self.s.api + '/user')
         r.raise_for_status()
         user = r.json()
         return self.is_member_of_group(group, user['username'])
