@@ -277,7 +277,8 @@ class Libvirt(object):
                        libvirt.VIR_NETWORK_SECTION_IP_DHCP_HOST,
                        -1,
                        xml,
-                       libvirt.VIR_NETWORK_UPDATE_AFFECT_CURRENT)
+                       (libvirt.VIR_NETWORK_UPDATE_AFFECT_LIVE |
+                        libvirt.VIR_NETWORK_UPDATE_AFFECT_CONFIG))
         return True
 
     def network_host_unset(self, name, host, mac, ip):
@@ -289,7 +290,8 @@ class Libvirt(object):
                        libvirt.VIR_NETWORK_SECTION_IP_DHCP_HOST,
                        -1,
                        xml,
-                       libvirt.VIR_NETWORK_UPDATE_AFFECT_CURRENT)
+                       (libvirt.VIR_NETWORK_UPDATE_AFFECT_LIVE |
+                        libvirt.VIR_NETWORK_UPDATE_AFFECT_CONFIG))
         return True
 
     def network_create(self, name, prefix):
