@@ -122,10 +122,9 @@ class Service(object):
             if not os.path.exists(playbook_file):
                 playbook_file = f'{self.share_dir}/{self.args["playbook"]}'
 
-        subset = f"{service}-service-group:{service}-client-group:&live"
         playbook.run([
             f'--private-key={self.dotenough.private_key()}',
-            '--limit', subset,
+            '--limit', ','.join(hosts + ['localhost']),
             playbook_file,
         ])
         return {'fqdn': f'{self.args["name"]}.{self.args["domain"]}'}
