@@ -8,7 +8,7 @@ def test_all(host):
     marker = "MARKER"
     key = 'playbooks/authorized_keys/roles/authorized_keys/files/test_keys/testkey'
     sh.chmod('600', key)
-    r = sh.ssh('-i', key, 'debian@' + address, 'echo', marker)
+    r = sh.ssh('-oStrictHostKeyChecking=no', '-i', key, 'debian@' + address, 'echo', marker)
     assert r.stdout.decode('utf-8').strip() == marker
 
 
